aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Graphics/Shader/je_shader.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Graphics/Shader/je_shader.cpp')
-rw-r--r--src/libjin/Graphics/Shader/je_shader.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/libjin/Graphics/Shader/je_shader.cpp b/src/libjin/Graphics/Shader/je_shader.cpp
index 686f2b9..19485b9 100644
--- a/src/libjin/Graphics/Shader/je_shader.cpp
+++ b/src/libjin/Graphics/Shader/je_shader.cpp
@@ -9,12 +9,12 @@
#include "je_shader.h"
-namespace jin
+namespace JinEngine
{
- namespace graphics
+ namespace Graphics
{
- using namespace jin::filesystem;
+ using namespace JinEngine::Filesystem;
using namespace std;
//
@@ -258,7 +258,7 @@ namespace jin
);
}
- void Shader::sendMatrix4(const char* name, const math::Matrix* mat4)
+ void Shader::sendMatrix4(const char* name, const Math::Matrix* mat4)
{
int loc = glGetUniformLocation(mPID, name);
glUniformMatrix4fv(loc, 1, GL_FALSE, mat4->getElements());
@@ -278,7 +278,7 @@ namespace jin
glVertexAttribPointer(loc, n, type, GL_FALSE, stride, pointers);
}
- } // namespace graphics
-} // namespace jin
+ } // namespace Graphics
+} // namespace JinEngine
#endif // jin_graphics_shader \ No newline at end of file